Quickstart
===========

After you've followed the instructions from the :doc:`installation` page,
you can configure the application.

1. Insert usercode and password, then press "Try login credentials". If you
get a text saying ``Successful login``, continue to step 2

2. Go to the ``Courses`` tab, click ``Refresh list``. Wait a few seconds.
A list of all the available courses should come up. For every course,
you can choose to synchronize it by checking the corresponding checkbox;
you can also choose the folder name under which every file belonging to
the course should be saved. Two different courses can't use the same
folder.

3. Go back to the ``General settings`` tab, press the ``Change`` button
if you don't like the predefined root folder (i.e the folder under which
every course is saved). The other options should be self-explanatory.

4. Press ``Sync now`` to start the first synchronization.

Nothing happens, what should I do?
----------------

First of all, check the ``Status`` tab. This tab is used to show various messages,
errors included.

If you get ``I can't connect to the server. Is the Internet connection working?``,
or ``The timeout time has been reached. Is the Internet connection working?``,
as the messages say, the program couldn't connect to the BeeP website. Check if
your Internet connection is working. Then you could try ``sync now`` and see if
the problem persists.

If you get ``Login failed.``, it means that the User code or the password is
wrong (or both are).

If you still have problems, or other errors come up, `send me an e-mail <mailto:ubuntupk@gmail.com?Subject=[poliBeePsync]%20error>`_.